@@ -1,7 +1,7 @@
 /*
  * Copyright 2000, International Business Machines Corporation and others.
  * All Rights Reserved.
- * 
+ *
  * This software has been released under the terms of the IBM Public
  * License.  For details, see the LICENSE file in the top-level source
  * directory or online at http://www.openafs.org/dl/license10.html
@@ -29,7 +29,7 @@
 #include <errno.h>
 #include <string.h>
 #include <ctype.h>
-    
+
 #include <rx/xdr.h>
 #include <rx/rx.h>
 #include <stdio.h>
@@ -83,7 +83,7 @@ afsconf_GetNoAuthFlag(struct afsconf_dir *adir)
 void
 afsconf_SetNoAuthFlag(struct afsconf_dir *adir, int aflag)
 {
-    register afs_int32 code;
+    afs_int32 code;
 
     LOCK_GLOBAL_MUTEX;
     if (aflag == 0) {
@@ -106,18 +106,18 @@ afsconf_SetNoAuthFlag(struct afsconf_dir *adir, int aflag)
 
 /* deletes a user from the UserList file */
 int
-afsconf_DeleteUser(struct afsconf_dir *adir, register char *auser)
+afsconf_DeleteUser(struct afsconf_dir *adir, char *auser)
 {
     char tbuffer[1024];
     char nbuffer[1024];
-    register FILE *tf;
-    register FILE *nf;
-    register int flag;
+    FILE *tf;
+    FILE *nf;
+    int flag;
     char tname[64 + 1];
     char *tp;
     int found;
     struct stat tstat;
-    register afs_int32 code;
+    afs_int32 code;
 
     LOCK_GLOBAL_MUTEX;
     strcompose(tbuffer, sizeof tbuffer, adir->name, "/",
@@ -196,15 +196,15 @@ afsconf_DeleteUser(struct afsconf_dir *adir, register char *auser)
 
 /* returns nth super user from the UserList file */
 int
-afsconf_GetNthUser(struct afsconf_dir *adir, afs_int32 an, char *abuffer, 
+afsconf_GetNthUser(struct afsconf_dir *adir, afs_int32 an, char *abuffer,
 		   afs_int32 abufferLen)
 {
     char tbuffer[256];
-    register FILE *tf;
+    FILE *tf;
     char tname[64 + 1];
-    register char *tp;
-    register int flag;
-    register afs_int32 code;
+    char *tp;
+    int flag;
+    afs_int32 code;
 
     LOCK_GLOBAL_MUTEX;
     strcompose(tbuffer, sizeof tbuffer, adir->name, "/",
@@ -235,13 +235,13 @@ afsconf_GetNthUser(struct afsconf_dir *adir, afs_int32 an, char *abuffer,
 
 /* returns true iff user is in the UserList file */
 static int
-FindUser(struct afsconf_dir *adir, register char *auser)
+FindUser(struct afsconf_dir *adir, char *auser)
 {
     char tbuffer[256];
-    register bufio_p bp;
+    bufio_p bp;
     char tname[64 + 1];
-    register int flag;
-    register afs_int32 code;
+    int flag;
+    afs_int32 code;
     int rc;
 
     strcompose(tbuffer, sizeof tbuffer, adir->name, "/", AFSDIR_ULIST_FILE,
@@ -270,7 +270,7 @@ int
 afsconf_AddUser(struct afsconf_dir *adir, char *aname)
 {
     FILE *tf;
-    register afs_int32 code;
+    afs_int32 code;
     char tbuffer[256];
 
     LOCK_GLOBAL_MUTEX;
@@ -297,11 +297,11 @@ afsconf_AddUser(struct afsconf_dir *adir, char *aname)
 }
 
 /* special CompFindUser routine that builds up a princ and then
-	calls finduser on it. If found, returns char * to user string, 
+	calls finduser on it. If found, returns char * to user string,
 	otherwise returns NULL. The resulting string should be immediately
 	copied to other storage prior to release of mutex. */
 static char *
-CompFindUser(struct afsconf_dir *adir, char *name, char *sep, char *inst, 
+CompFindUser(struct afsconf_dir *adir, char *name, char *sep, char *inst,
 	     char *realm)
 {
     static char fullname[MAXKTCNAMELEN + MAXKTCNAMELEN + MAXKTCREALMLEN + 3];
@@ -310,7 +310,9 @@ CompFindUser(struct afsconf_dir *adir, char *name, char *sep, char *inst,
     if (!name || !name[0]) {
 	return NULL;
     }
-    strcpy(fullname, name);
+
+    if (strlcpy(fullname, name, sizeof(fullname)) >= sizeof(fullname))
+	return NULL;
 
     /* might have instance */
     if (inst && inst[0]) {
@@ -318,14 +320,20 @@ CompFindUser(struct afsconf_dir *adir, char *name, char *sep, char *inst,
 	    return NULL;
 	}
 
-	strcat(fullname, sep);
-	strcat(fullname, inst);
+	if (strlcat(fullname, sep, sizeof(fullname)) >= sizeof(fullname))
+	    return NULL;
+
+	if (strlcat(fullname, inst, sizeof(fullname)) >= sizeof(fullname))
+	    return NULL;
     }
 
     /* might have realm */
     if (realm && realm[0]) {
-	strcat(fullname, "@");
-	strcat(fullname, realm);
+	if (strlcat(fullname, "@", sizeof(fullname)) >= sizeof(fullname))
+	    return NULL;
+
+	if (strlcat(fullname, realm, sizeof(fullname)) >= sizeof(fullname))
+	    return NULL;
     }
 
     if (FindUser(adir, fullname)) {
@@ -343,8 +351,8 @@ CompFindUser(struct afsconf_dir *adir, char *name, char *sep, char *inst,
 afs_int32
 afsconf_SuperUser(struct afsconf_dir *adir, struct rx_call *acall, char *namep)
 {
-    register struct rx_connection *tconn;
-    register afs_int32 code;
+    struct rx_connection *tconn;
+    afs_int32 code;
     int flag;
 
     LOCK_GLOBAL_MUTEX;
@@ -443,7 +451,7 @@ afsconf_SuperUser(struct afsconf_dir *adir, struct rx_call *acall, char *namep)
 	    }
 	}
 
-	/* If yes, then make sure that the name is not present in 
+	/* If yes, then make sure that the name is not present in
 	 * an exclusion list */
 	if (lrealm_match) {
 	    if (tinst[0])
